/**
 * Copyright (c) 2009-2012 EBM WebSourcing, 2012-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.kernel.ws.api;

import java.net.URL;

import javax.jws.WebMethod;
import javax.jws.WebParam;
import javax.jws.WebService;

/**
 * The installation service deals with JBI component lifecycle stuff.
 * @author Christophe HAMERLING - EBM WebSourcing
 */
@WebService
public interface InstallationService {

    /**
     * Install a component which is available in the artifact repository (@see
     * {@link ArtifactRepositoryService})
     *
     * @param componentId
     * @return
     */
    @WebMethod(operationName = "installFromRepository")
    boolean install(@WebParam(name = "componentId") String componentId)
            throws PEtALSWebServiceException;

    /**
     * Install a component from its URL (the component can be somewhere outside
     * of the PEtALS context)
     *
     * @param url
     * @return
     */
    @WebMethod
    boolean install(@WebParam(name = "url") URL url) throws PEtALSWebServiceException;

    /**
     * Uninstall a component
     *
     * @param componentId
     * @return
     */
    @WebMethod
    boolean uninstall(@WebParam(name = "componentId") String componentId)
            throws PEtALSWebServiceException;

}
