/**
 * Copyright (c) 2009-2012 EBM WebSourcing, 2012-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.kernel.ws.api;

import java.util.List;

import javax.jws.WebMethod;
import javax.jws.WebParam;
import javax.jws.WebService;

import org.ow2.petals.kernel.ws.api.to.ContainerInformation;
import org.ow2.petals.kernel.ws.api.to.DomainInformation;
import org.ow2.petals.kernel.ws.api.to.JndiInformation;
import org.ow2.petals.kernel.ws.api.to.SubdomainInformation;
import org.ow2.petals.kernel.ws.api.to.SubdomainInformation.SubdomainMode;

/**
 * Get information from topology.
 *
 * @author Christophe HAMERLING - EBM WebSourcing
 * @author Charles Casadei - EBM WebSourcing
 */
@WebService
public interface TopologyService {

    /**
     * Get the information on the global JNDI.
     *
     * @return
     * @throws PEtALSWebServiceException
     */
    @WebMethod
    JndiInformation getJndiInformation() throws PEtALSWebServiceException;

    /**
     * Retrieve all the domain-related informations
     *
     * @return
     * @throws PEtALSWebServiceException
     */
    @WebMethod
    DomainInformation getDomainInformation() throws PEtALSWebServiceException;

    /**
     * Add a subdomain to the topology, without adding any containers.
     *
     * @param name
     * @param description
     * @param subdomainMode
     * @param networkTimeSynchronized
     */
    @WebMethod
    void addSubdomain(
            @WebParam(name="subdomain-name")
            String name,
            @WebParam(name="subdomain-description")
            String description,
            @WebParam(name="subdomain-mode")
            SubdomainMode subdomainMode,
            @WebParam(name="network-time-synchronized")
            boolean networkTimeSynchronized)
            throws PEtALSWebServiceException;

    /**
     * Add a subdomain to the topology with a potentially a whole set of
     * containers.
     *
     * @param subdomain
     * @throws PEtALSWebServiceException
     */
    @WebMethod
    void addSubdomainWithContainers(
            @WebParam(name="subdomain")
            SubdomainInformation subdomain)
            throws PEtALSWebServiceException;

    /**
     * Get the subdomain with the given name
     *
     * @param subdomainName
     * @return
     * @throws PEtALSWebServiceException
     */
    SubdomainInformation getSubdomainByName(
            @WebParam(name="subdomain-name")
            String subdomainName)
            throws PEtALSWebServiceException;

    void removeSubdomain(
            @WebParam(name="subdomain-name")
            String subdomainName)
            throws PEtALSWebServiceException;

    /**
     * Add a new container onto the list of registered containers.
     * 
     * @param newContainer
     * @param subdomainName
     *            The sub-domain name in which the container must be added
     * @throws PEtALSWebServiceException
     */
    @WebMethod
    void addContainerInformation(
            @WebParam(name="added-container")
            ContainerInformation addedContainer,
            @WebParam(name="subdomain-name")
            String subdomainName)
            throws PEtALSWebServiceException;

    /**
     * Get the information for all the known containers
     *
     * @return
     * @throws PEtALSWebServiceException
     */
    @WebMethod
    List<ContainerInformation> getAllContainerInformation()
            throws PEtALSWebServiceException;

    /**
     * Get the container information for a given container
     *
     * @param containerId
     * @return
     * @throws PEtALSWebServiceException
     *             if the containerId is not know in the petals topology
     */
    @WebMethod
    ContainerInformation getContainerInformation(
            @WebParam(name="container-name")
            String containerName)
            throws PEtALSWebServiceException;

    @WebMethod
    void removeContainerInformation(
            @WebParam(name="container-Name")
            String containerName)
            throws PEtALSWebServiceException;
}
