/**
 * Copyright (c) 2009-2012 EBM WebSourcing, 2012-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.kernel.ws.api.to;

import java.util.List;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;

import org.ow2.petals.kernel.ws.api.Constants;

/**
 * @author Charles Casadei - EBM WebSourcing
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(namespace = Constants.NS, name = "domain-information")
public class DomainInformation {

    @XmlElement(name="domain-revision", required=true, nillable=false)
    private long revision;

    @XmlElement(name="domain-name", required=true, nillable=false)
    private String name;

    @XmlElement(name="domain-description", required=false, nillable=true)
    private String description;

    @XmlElement(name="domain-jndi", required=false, nillable=true)
    private JndiInformation jndi;

    @XmlElement(name="domain-subdomains", required=true, nillable=false)
    private List<SubdomainInformation> subdomains;

    public DomainInformation() {

    }

    public long getRevision() {
        return this.revision;
    }

    public void setRevision(long revision) {
        this.revision = revision;
    }

    public String getName() {
        return this.name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getDescription() {
        return this.description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public JndiInformation getJndi() {
        return this.jndi;
    }

    public void setJndiInformation(JndiInformation jndi) {
        this.jndi = jndi;
    }

    public List<SubdomainInformation> getSubdomains() {
        return this.subdomains;
    }

    public void setSubdomains(List<SubdomainInformation> subdomains) {
        this.subdomains = subdomains;
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }

        if (this.getClass() != obj.getClass()) {
            return false;
        }

        final DomainInformation other = (DomainInformation) obj;
        if (this.revision != other.revision) {
            return false;
        }

        if ((this.name == null) ? (other.name != null) : !this.name.equals(other.name)) {
            return false;
        }

        if ((this.description == null) ? (other.description != null) : !this.description.equals(other.description)) {
            return false;
        }

        if ((this.jndi != other.jndi) && ((this.jndi == null) || !this.jndi.equals(other.jndi))) {
            return false;
        }

        if ((this.subdomains != other.subdomains) && ((this.subdomains == null) || !this.subdomains.equals(other.subdomains))) {
            return false;
        }

        if ((this.subdomains != null) && (other.subdomains != null)) {
            if (this.subdomains.size() != other.subdomains.size()) {
                return false;
            }

            for (SubdomainInformation container : this.subdomains) {
                if (! other.subdomains.contains(container)) {
                    return false;
                }
            }
        }

        return true;
    }

    @Override
    public int hashCode() {
        int hash = 3;
        hash = 17 * hash + (int) (this.revision ^ (this.revision >>> 32));
        hash = 17 * hash + (this.name != null ? this.name.hashCode() : 0);
        hash = 17 * hash + (this.description != null ? this.description.hashCode() : 0);
        hash = 17 * hash + (this.jndi != null ? this.jndi.hashCode() : 0);
        hash = 17 * hash + (this.subdomains != null ? this.subdomains.size() : 0);
        return hash;
    }

    @Override
    public String toString() {
        StringBuilder toStringBuilder = new StringBuilder();
        toStringBuilder.append("DomainInformation [");
        toStringBuilder.append("domain-name=").append(this.name).append(", ");
        toStringBuilder.append("domain-description=").append(this.description).append(", ");
        toStringBuilder.append("domain-jndi=").append(this.jndi).append(", ");
        toStringBuilder.append("domain-subdomains={");

        if (this.subdomains != null) {
            for (SubdomainInformation subdomain : this.subdomains) {
                toStringBuilder.append(subdomain).append(", ");
            }
        }

        toStringBuilder.append("}]");

        return toStringBuilder.toString();
    }

}
