/**
 * Copyright (c) 2009-2012 EBM WebSourcing, 2012-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.kernel.ws.api.to;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;

import org.ow2.petals.kernel.ws.api.Constants;

/**
 * @author Charles Casadei - EBM WebSourcing
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(namespace = Constants.NS, name = "jndi-information")
public class JndiInformation {

    @XmlElement(name="jndi-factory", required=true, nillable=false)
    private String factory;

    @XmlElement(name="jndi-provider-url", required=true, nillable=false)
    private String providerUrl;

    @XmlElement(name="jndi-security-principal", required=false, nillable=true)
    private String securityPrincipal;

    @XmlElement(name="jndi-security-credentials", required=false, nillable=true)
    private String securityCredentials;

    @XmlElement(name="jndi-pool-size", required=false, nillable=true)
    private int poolSize;

    @XmlElement(name="jndi-batch-size", required=false, nillable=true)
    private int batchSize;

    public JndiInformation() {

    }

    public String getFactory() {
        return factory;
    }

    public void setFactory(String factory) {
        this.factory = factory;
    }

    public String getProviderUrl() {
        return providerUrl;
    }

    public void setProviderUrl(String providerUrl) {
        this.providerUrl = providerUrl;
    }

    public String getSecurityPrincipal() {
        return securityPrincipal;
    }

    public void setSecurityPrincipal(String securityPrincipal) {
        this.securityPrincipal = securityPrincipal;
    }

    public String getSecurityCredentials() {
        return securityCredentials;
    }

    public void setSecurityCredentials(String securityCredentials) {
        this.securityCredentials = securityCredentials;
    }

    public int getPoolSize() {
        return poolSize;
    }

    public void setPoolSize(int poolSize) {
        this.poolSize = poolSize;
    }

    public int getBatchSize() {
        return batchSize;
    }

    public void setBatchSize(int batchSize) {
        this.batchSize = batchSize;
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }

        if (getClass() != obj.getClass()) {
            return false;
        }

        final JndiInformation other = (JndiInformation) obj;
        if ((this.factory == null) ? (other.factory != null) : !this.factory.equals(other.factory)) {
            return false;
        }

        if ((this.providerUrl == null) ? (other.providerUrl != null) : !this.providerUrl.equals(other.providerUrl)) {
            return false;
        }

        if ((this.securityPrincipal == null) ? (other.securityPrincipal != null) : !this.securityPrincipal.equals(other.securityPrincipal)) {
            return false;
        }

        if ((this.securityCredentials == null) ? (other.securityCredentials != null) : !this.securityCredentials.equals(other.securityCredentials)) {
            return false;
        }

        if (this.poolSize != other.poolSize) {
            return false;
        }

        if (this.batchSize != other.batchSize) {
            return false;
        }

        return true;
    }

    @Override
    public int hashCode() {
        int hash = 7;
        hash = 67 * hash + (this.factory != null ? this.factory.hashCode() : 0);
        hash = 67 * hash + (this.providerUrl != null ? this.providerUrl.hashCode() : 0);
        hash = 67 * hash + (this.securityPrincipal != null ? this.securityPrincipal.hashCode() : 0);
        hash = 67 * hash + (this.securityCredentials != null ? this.securityCredentials.hashCode() : 0);
        hash = 67 * hash + this.poolSize;
        hash = 67 * hash + this.batchSize;
        return hash;
    }

    @Override
    public String toString() {
        StringBuilder toStringBuilder = new StringBuilder();
        toStringBuilder.append("JndiInformation [");
        toStringBuilder.append("jndi-factory=").append(this.factory).append(", ");
        toStringBuilder.append("jndi-provider-url=").append(this.providerUrl).append(", ");
        toStringBuilder.append("jndi-security-principal=").append(this.securityPrincipal).append(", ");
        toStringBuilder.append("jndi-security-credentials=").append(this.securityCredentials).append(", ");
        toStringBuilder.append("jndi-pool-size=").append(this.poolSize).append(", ");
        toStringBuilder.append("jndi-batch-size=").append(this.batchSize).append("]");

        return toStringBuilder.toString();
    }
}
